==> v11.0.3-2020-05-20-07-31-09.zip: htdocs/install/mysql/tables/llx_projet_task_time.sql <==
-- ===========================================================================
-- Copyright (C) 2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program. If not, see <https://www.gnu.org/licenses/>.
--
-- ===========================================================================

create table llx_projet_task_time
(
  rowid            integer AUTO_INCREMENT PRIMARY KEY,
  fk_task          integer NOT NULL,
  task_date        date,					-- only the day
  task_datehour    datetime,				-- day + hour
  task_date_withhour integer DEFAULT 0,	-- 0 by default, 1 if date was entered with start hour
  task_duration    double,
  fk_user          integer,
  thm			   double(24,8),
  invoice_id       integer DEFAULT NULL,				-- If we need to invoice each line of timespent, we can save invoice id here
  invoice_line_id  integer DEFAULT NULL,                -- If we need to invoice each line of timespent, we can save invoice line id here
  import_key	   varchar(14),					-- Import key
  datec            date,						-- Date creation time
  tms              timestamp,					-- Date update time
  note             text							-- A comment
)ENGINE=innodb;

==> v15.0.0-2022-04-04-11-24-13.zip: htdocs/install/mysql/tables/llx_projet_task_time.sql <==
-- ===========================================================================
-- Copyright (C) 2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program. If not, see <https://www.gnu.org/licenses/>.
--
-- ===========================================================================

create table llx_projet_task_time
(
  rowid            integer AUTO_INCREMENT PRIMARY KEY,
  fk_task          integer NOT NULL,
  task_date        date,					-- only the day
  task_datehour    datetime,				-- day + hour
  task_date_withhour integer DEFAULT 0,	-- 0 by default, 1 if date was entered with start hour
  task_duration    double,
  fk_user          integer,
  thm			   double(24,8),
  invoice_id       integer DEFAULT NULL,				-- If we need to invoice each line of timespent, we can save invoice id here
  invoice_line_id  integer DEFAULT NULL,                -- If we need to invoice each line of timespent, we can save invoice line id here
  import_key	   varchar(14),					-- Import key
  datec            datetime,					-- date creation time
  tms              timestamp DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,					-- last modification date
  note             text							-- A comment
)ENGINE=innodb;
